==> docx4j-openxml-objects-8.0.0-sources.jar: org/docx4j/dml/diagram/STAnimLvlStr.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_AnimLvlStr.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_AnimLvlStr">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token">
 *     &lt;enumeration value="none"/>
 *     &lt;enumeration value="lvl"/>
 *     &lt;enumeration value="ctr"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_AnimLvlStr")
@XmlEnum
public enum STAnimLvlStr {


    /**
     * Disable Level At Once
     * 
     */
    @XmlEnumValue("none")
    NONE("none"),

    /**
     * By Level Animation
     * 
     */
    @XmlEnumValue("lvl")
    LVL("lvl"),

    /**
     * From Center Animation
     * 
     */
    @XmlEnumValue("ctr")
    CTR("ctr");
    private final String value;

    STAnimLvlStr(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STAnimLvlStr fromValue(String v) {
        for (STAnimLvlStr c: STAnimLvlStr.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-8.3.12-sources.jar: org/docx4j/dml/diagram/STAnimLvlStr.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml.diagram;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_AnimLvlStr.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_AnimLvlStr"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}token"&gt;
 *     &lt;enumeration value="none"/&gt;
 *     &lt;enumeration value="lvl"/&gt;
 *     &lt;enumeration value="ctr"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "ST_AnimLvlStr")
@XmlEnum
public enum STAnimLvlStr {


    /**
     * Disable Level At Once
     * 
     */
    @XmlEnumValue("none")
    NONE("none"),

    /**
     * By Level Animation
     * 
     */
    @XmlEnumValue("lvl")
    LVL("lvl"),

    /**
     * From Center Animation
     * 
     */
    @XmlEnumValue("ctr")
    CTR("ctr");
    private final String value;

    STAnimLvlStr(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STAnimLvlStr fromValue(String v) {
        for (STAnimLvlStr c: STAnimLvlStr.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
